(***********************************************************************)
(*                                                                     *)
(*                               TAToo                                 *)
(*                                                                     *)
(*                     Kim Nguyen, LRI UMR8623                         *)
(*                   Université Paris-Sud & CNRS                       *)
(*                                                                     *)
(*  Copyright 2010-2012 Université Paris-Sud and Centre National de la *)
(*  Recherche Scientifique. All rights reserved.  This file is         *)
(*  distributed under the terms of the GNU Lesser General Public       *)
(*  License, with the special exception on linking described in file   *)
(*  ../LICENSE.                                                        *)
(*                                                                     *)
(***********************************************************************)

(*
  Time-stamp: <Last modified on 2013-03-04 22:48:34 CET by Kim Nguyen>
*)

(** Implementation of qualified names as hashconsed strings *)

include Hcons.S with type data = string
include Common_sig.Printable with type t := t


val of_string : string -> t
(** Utility function, equivalent to [make] *)

val to_string : t -> string
(** Utility function, equivalent to [node] *)


(** Special constants, that denote the QName of nodes that are not
    elements (using the nodeValue property of DOM for such nodes.
*)

val document : t
(** Represents the QName of a document node. Equivalent to
    [of_string "#document"]
*)

val text : t
(** Represents the QName of a text node. Equivalent to
    [of_string "#text"]
*)

val cdata_section : t
(** Represents the QName of a document node. Equivalent to
    [of_string "#cdata-section"]
*)

val comment : t
(** Represents the QName of a comment node. Equivalent to
    [of_string "#comment"]
*)

val document_fragment : t
(** Represents the QName of a document fragment. Equivalent to
    [of_string "#document-fragment"]
*)

val attribute_map : t
(** Represents the QName of a dummy document node holding the
    attributes of the current element. Equivalent to
    [of_string "#attribute-map"]
*)

val nil : t
(** Represents the QName of a nil node. Equivalent to
    [of_string "#"]
*)

val attribute_prefix : t
(** Represents a prefix that may be prepended to attribute name
    to distinguish them from element names
*)

val has_attribute_prefix : t -> bool
(** Tests whether the given QName starts with the attribute prefix
*)

val add_attribute_prefix : t -> t
(** Prepends the attribute_prefix to the given QName *)
